@@ -14,7 +14,7 @@ testthat::context("base tests")
         # cat("a = ", a, "b = ", b, "\n")
         res <- try(gsDesign(test.type = type, alpha = a, beta = b, sfu = sf))
 
-        if (is(res, "try-error")) {
+        if (inherits(res, "try-error")) {
           no.err <- FALSE
         }
       }
@@ -31,7 +31,7 @@ testthat::context("base tests")
   {
     res <- try(gsDesign(test.type = type, sfu = sf, sfupar = p))
 
-    if (is(res, "try-error")) {
+    if (inherits(res, "try-error")) {
       no.err <- FALSE
     }
   }
